@@ -89,8 +89,19 @@ class db:
             self.commits       += 1
             self.commited_rows += self.running_commands
 
+        self.close()
+
+    def close(self):
+        """ close self.dbconn PostgreSQL connection """
         if self.dbconn is not None:
+            try:
+                self.log.info('closing current database connection')
+            except IOError, e:
+                # Ignore no space left on device etc here
+                pass
+            
             self.dbconn.close()
+            self.dbconn = None
 
     def set_encoding(self):
         """ set connection encoding to self.client_encoding """
@@ -195,10 +206,7 @@ ORDER BY attnum
         self.partial_coldef    = None
 
         try:
-            if self.dbconn is not None:
-                self.log.debug('Debug: closing current connection')
-                self.dbconn.close()
-
+            self.close()
             self.log.debug('Debug: connecting to dns %s', self.dsn)
 
             self.dbconn = psycopg.connect(self.dsn)
@@ -409,17 +417,6 @@ ORDER BY attnum
         ok = True
         if not self.copy: self.copy = True
 
-        ##
-        # build the table colomns specs from parameters
-        # ie. we always issue COPY table (col1, col2, ..., coln) commands
-        tablename = table
-        if self.all_cols:
-            table = table
-        else:
-            table = "%s (%s) " % (table, ", ".join(columnlist))
-
-        self.log.debug("COPY will use table definition: '%s'" % table)
-
         if EOF or self.running_commands == self.copy_every \
                and self.buffer is not None:
             # time to copy data to PostgreSQL table
@@ -428,6 +425,17 @@ ORDER BY attnum
                 self.log.warning("no data to COPY")
                 return False
             
+            ##
+            # build the table colomns specs from parameters
+            # ie. we always issue COPY table (col1, col2, ..., coln) commands
+            tablename = table
+            if self.all_cols:
+                table = table
+            else:
+                table = "%s (%s) " % (table, ", ".join(columnlist))
+
+            self.log.debug("COPY will use table definition: '%s'" % table)
+                
             if CLIENT_MIN_MESSAGES <= logging.DEBUG:
                 self.save_copy_buffer(tablename, debug = True)
 
